#!/bin/bash
source process_subtraction.cfg



# Variables that should not be modified:
verbose=false

# num_parallel_jobs * set_maxNumCompThreads must be smaller or equal to the total amount of cores available.
# It is highly recommended to increase num_parallel_jobs instead of set_maxNumCompThreads!
set_maxNumCompThreads=1

default_file_extension=".mrc"


# ----------------------------------------------------------------------
# Process inputs
# ----------------------------------------------------------------------

# Check if the input ends with the default file extension
if [[ "${input}" != *$default_file_extension ]]; then
    # Assume input is a directory and append /*.pdf to it
    input="${input}/*${default_file_extension}"
fi
# Initialize an empty array
fs_in=()
# Read files into the array, handling spaces and special characters properly
while IFS= read -r -d $'\0' file; do
  fs_in+=("$file")
done < <(find $(dirname "$input") -maxdepth 1 -name "$(basename "$input")" -print0)





# Product of set_maxNumCompThreads and num_parallel_jobs
requested_threads=$(( set_maxNumCompThreads * num_parallel_jobs ))
# Get the number of available cores
available_cores=$(nproc)
# Check if total_threads is greater than available_cores
if (( total_threads > available_cores )); then
  echo "Error: The requested number of threads (${total_threads}) exceeds the number of available cores (${available_cores})."
  exit 1
fi




mkdir -p $output_dir

export PATH=$PATH:$path_to_matlab_bin

function run_lsub_matlab ()
{
        of=${1##*/}
        #-singleCompThread
        matlab -nodisplay -nosplash -nodesktop -r "\
        maxNumCompThreads(${set_maxNumCompThreads});\
        addpath '${addpath_m}';\
        Pad_Origin_X=${Pad_Origin_X};\
        Pad_Origin_Y=${Pad_Origin_Y};\
        Inside_Radius_Ang=${Inside_Radius_Ang};\
        Outside_Radius_Ang=${Outside_Radius_Ang};\
        Pixel_Ang=${Pixel_Ang};\
        Threshold=${Threshold};\
        expand_pixel=${expand_pixel};\
        pad_out_opt=${pad_out_opt};\
        name_list='${1}';\
        name_sub='${output_dir}/${of}';\
        run('${path_matlab_script}');\
        exit;"
}

num_files=${#fs_in[@]}
N=$num_parallel_jobs
count=0
time (
for filein in ${fs_in[@]}; do
        count=$((count+1))
        fileout=${output_dir}/${filein##*/}
        printf "(%05d/%05d)\t" $count $num_files
        if [ -f "$fileout" ] && [ $only_do_unfinished == true ] ; then
                echo "skipping: $filein (does already exist)"
                continue
        fi
        ((i=i%N)); ((i++==0)) && wait
        echo "processing: $filein"
        if [ $verbose == true ] ; then
                run_lsub_matlab "$filein" &
        else
                run_lsub_matlab "$filein" 1> /dev/null &
        fi
        sleep 0.4
done && wait
)

